@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1999-2015 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 1999-2018 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** All rights reserved.
 **
@@ -39,6 +39,8 @@
 
 #if HAVE_UNISTD_H
 #include <unistd.h>
+#else
+#include "sf_unistd.h"
 #endif
 
 #include <sndfile.h>
@@ -54,19 +56,15 @@
 
 #if defined (__ANDROID__)
 
-#elif defined (__linux__) || defined (__FreeBSD_kernel__) || defined (__FreeBSD__) || defined (__CYGWIN__)
+#elif defined (__linux__) || defined (__FreeBSD_kernel__) || defined (__FreeBSD__) || defined (__riscos__) || defined (__CYGWIN__)
 	#include 	<fcntl.h>
 	#include 	<sys/ioctl.h>
 	#include 	<sys/soundcard.h>
 
-#elif (defined (__MACH__) && defined (__APPLE__))
-	#include <AvailabilityMacros.h>
-	#include <Availability.h>
-
 #elif HAVE_SNDIO_H
 	#include <sndio.h>
 
-#elif (defined (sun) && defined (unix))
+#elif (defined (sun) && defined (unix)) || defined(__NetBSD__)
 	#include <fcntl.h>
 	#include <sys/ioctl.h>
 	#include <sys/audioio.h>
@@ -121,10 +119,10 @@ alsa_play (int argc, char *argv [])
 			int 	m ;
 
 			sf_command (sndfile, SFC_CALC_SIGNAL_MAX, &scale, sizeof (scale)) ;
-			if (scale < 1e-10)
-				scale = 1.0 ;
+			if (scale > 1.0)
+				scale = 1.0 / scale ;
 			else
-				scale = 32700.0 / scale ;
+				scale = 1.0 ;
 
 			while ((readcount = sf_read_float (sndfile, buffer, BUFFER_LEN)))
 			{	for (m = 0 ; m < readcount ; m++)
@@ -330,10 +328,12 @@ alsa_write_float (snd_pcm_t *alsa_dev, float *data, int frames, int channels)
 					return 0 ;
 					break ;
 
+#if defined ESTRPIPE && ESTRPIPE != EPIPE
 			case -ESTRPIPE :
 					fprintf (stderr, "alsa_write_float: Suspend event.n") ;
 					return 0 ;
 					break ;
+#endif
 
 			case -EIO :
 					puts ("alsa_write_float: EIO") ;
@@ -355,7 +355,7 @@ alsa_write_float (snd_pcm_t *alsa_dev, float *data, int frames, int channels)
 **	Linux/OSS functions for playing a sound.
 */
 
-#if !defined (__ANDROID__) && (defined (__linux__) || defined (__FreeBSD_kernel__) || defined (__FreeBSD__) || defined (__CYGWIN__))
+#if !defined (__ANDROID__) && (defined (__linux__) || defined (__FreeBSD_kernel__) || defined (__FreeBSD__) || defined (__riscos__)) || defined (__CYGWIN__)
 
 static	int	opensoundsys_open_device (int channels, int srate) ;
 
@@ -511,7 +511,8 @@ win32_play_data (Win32_Audio_Data *audio_data)
 	/* fill a buffer if there is more data and we can read it sucessfully */
 	readcount = (audio_data->remaining > audio_data->bufferlen) ? audio_data->bufferlen : (int) audio_data->remaining ;
 
-	thisread = (int) sf_read_short (audio_data->sndfile, (short *) (audio_data->whdr [audio_data->current].lpData), readcount) ;
+	short *lpData = (short *) (void *) audio_data->whdr [audio_data->current].lpData ;
+	thisread = (int) sf_read_short (audio_data->sndfile, lpData, readcount) ;
 
 	audio_data->remaining -= thisread ;
 
@@ -728,7 +729,7 @@ sndio_play (int argc, char *argv [])
 **	Solaris.
 */
 
-#if (defined (sun) && defined (unix)) /* ie Solaris */
+#if (defined (sun) && defined (unix)) || defined(__NetBSD__)
 
 static void
 solaris_play (int argc, char *argv [])
@@ -765,8 +766,6 @@ solaris_play (int argc, char *argv [])
 		audio_info.play.channels = sfinfo.channels ;
 		audio_info.play.precision = 16 ;
 		audio_info.play.encoding = AUDIO_ENCODING_LINEAR ;
-		audio_info.play.gain = AUDIO_MAX_GAIN ;
-		audio_info.play.balance = AUDIO_MID_BALANCE ;
 
 		if ((error = ioctl (audio_fd, AUDIO_SETINFO, &audio_info)))
 		{	perror ("ioctl (AUDIO_SETINFO) failed") ;
@@ -808,7 +807,7 @@ solaris_play (int argc, char *argv [])
 	return ;
 } /* solaris_play */
 
-#endif /* Solaris */
+#endif /* Solaris or NetBSD */
 
 /*==============================================================================
 **	Main function.
@@ -842,24 +841,16 @@ main (int argc, char *argv [])
 		else
 	#endif
 		opensoundsys_play (argc, argv) ;
-#elif defined (__FreeBSD_kernel__) || defined (__FreeBSD__) || defined (__CYGWIN__)
+#elif defined (__FreeBSD_kernel__) || defined (__FreeBSD__) || defined (__riscos__) || defined (__CYGWIN__)
 	opensoundsys_play (argc, argv) ;
 #elif HAVE_SNDIO_H
 	sndio_play (argc, argv) ;
-#elif (defined (sun) && defined (unix))
+#elif (defined (sun) && defined (unix)) || defined(__NetBSD__)
 	solaris_play (argc, argv) ;
 #elif (OS_IS_WIN32 == 1)
 	win32_play (argc, argv) ;
-#elif (defined (__MACH__) && defined (__APPLE__))
-	printf ("OS X 10.8 and later have a new Audio API.\n") ;
-	printf ("Someone needs to write code to use that API.\n") ;
-	return 1 ;
-#elif defined (__BEOS__)
-	printf ("This program cannot be compiled on BeOS.\n") ;
-	printf ("Instead, compile the file sfplay_beos.cpp.\n") ;
-	return 1 ;
 #else
-	puts ("*** Playing sound not yet supported on this platform.") ;
+	puts ("*** Playing sound not supported on this platform.") ;
 	puts ("*** Please feel free to submit a patch.") ;
 	return 1 ;
 #endif
